#ifndef DATEBAR_H
#define DATEBAR_H
#include <qwidget.h>
#include <qpixmap.h>
#include <qdatetime.h>
#include "imagedaterange.h"
#include "imagedaterangecollection.h"
#include "dateviewhandler.h"
class QToolButton;

class DateBar :public QWidget {
    Q_OBJECT

public:
    DateBar( QWidget* parent, const char* name = 0 );
    enum ViewType { DecadeView, YearView, MonthView, WeekView, DayView, HourView };

public slots:
    void setViewType( ViewType tp );
    void setDate( const QDateTime& date );
    void setData( const ImageDateRangeCollection& );
    void scrollLeft();
    void scrollRight();
    void scroll( int units );
    void zoomIn();
    void zoomOut();

signals:
    void canZoomIn( bool );
    void canZoomOut( bool );

public:
    // Overriden methods for internal purpose
    virtual QSize sizeHint() const;
    virtual QSize minimumSizeHint() const;
    virtual void paintEvent( QPaintEvent* event );
    virtual void resizeEvent( QResizeEvent* event );
    virtual void mousePressEvent( QMouseEvent* event );
    virtual void mouseMoveEvent( QMouseEvent* event );

protected:
    void redraw();
    void drawTickMarks( QPainter& p, const QRect& rect );
    void drawHistograms( QPainter& p, const QRect& rect );
    void drawFocusRectagle( QPainter& p, const QRect& rect );
    void zoom( int );
    QRect barAreaGeometry() const;
    int numberOfUnits() const;

private:
    QPixmap _buffer;
    ImageDateRangeCollection _dates;
    DecadeViewHandler _decadeViewHandler;
    YearViewHandler _yearViewHandler;
    MonthViewHandler _monthViewHandler;
    WeekViewHandler _weekViewHandler;
    DayViewHandler _dayViewHandler;
    HourViewHandler _hourViewHandler;
    DateViewHandler* _currentHandler;
    ViewType _tp;

    QToolButton* _rightArrow;
    QToolButton* _leftArrow;
    QToolButton* _zoomIn;
    QToolButton* _zoomOut;

    int _currentUnit;
    QDateTime _currentDate;
    bool _movingBar;
    int _movementOffset;
};


#endif /* DATEBAR_H */

