#include "dateviewhandler.h"


void DateViewHandler::init( const QDateTime& startDate )
{
    _startDate = startDate;
}

bool DateViewHandler::isMidUnit( int /*unit*/ )
{
    return false;
}








void DecadeViewHandler::init( const QDateTime& startDate )
{
    QDateTime date = QDateTime( QDate( startDate.date().year(), 1, 1 ), QTime( 0,0,0 ) );
    DateViewHandler::init( date );
}

bool DecadeViewHandler::isMajorUnit( int unit )
{
    return date(unit).date().year() % 10 == 0;
}

bool DecadeViewHandler::isMidUnit( int unit )
{
    return date(unit).date().year() % 5 == 0;
}

QString DecadeViewHandler::text( int unit )
{
    return QString::number( date( unit ).date().year() );
}

QDateTime DecadeViewHandler::date(int unit, QDateTime reference )
{
    if ( reference.isNull() ) reference = _startDate;
    return reference.addMonths( 12*unit );
}





void YearViewHandler::init( const QDateTime& startDate )
{
    QDateTime date = QDateTime( QDate( startDate.date().year(), startDate.date().month(), 1 ), QTime( 0,0,0 ) );
    DateViewHandler::init( date );
}

bool YearViewHandler::isMajorUnit( int unit )
{
    return date(unit).date().month() == 1;
}

bool YearViewHandler::isMidUnit( int unit )
{
    return date( unit ).date().month() == 7;
}

QString YearViewHandler::text( int unit )
{
    return QString::number( date( unit ).date().year() );
}

QDateTime YearViewHandler::date(int unit, QDateTime reference )
{
    if ( reference.isNull() ) reference = _startDate;
    return reference.addMonths( unit );
}







void MonthViewHandler::init( const QDateTime& startDate)
{
    QDate date = startDate.date().addDays( - startDate.date().dayOfWeek() +1 ); // Wind to monday
    DateViewHandler::init( QDateTime( date, QTime( 0, 0, 0 ) ) );
}

bool MonthViewHandler::isMajorUnit( int unit )
{
    return date(unit).date().day() <= 7;
}

QString MonthViewHandler::text( int unit )
{
    return date(unit).toString( QString::fromLatin1( "d/M-yy" ) );
}

QDateTime MonthViewHandler::date(int unit, QDateTime reference )
{
    if ( reference.isNull() ) reference = _startDate;
    return reference.addDays( 7*unit );
}





void WeekViewHandler::init( const QDateTime& startDate)
{
    DateViewHandler::init( QDateTime( startDate.date(), QTime( 0, 0, 0 ) ) );
}

bool WeekViewHandler::isMajorUnit( int unit )
{
    return date(unit).date().dayOfWeek() == 1;
}

QString WeekViewHandler::text( int unit )
{
    return date(unit).toString( QString::fromLatin1( "d/M-yy" ) );
}

QDateTime WeekViewHandler::date(int unit, QDateTime reference )
{
    if ( reference.isNull() ) reference = _startDate;
    return reference.addDays( unit );
}





void DayViewHandler::init( const QDateTime& startDate)
{
    QDateTime date = startDate;
    if ( date.time().hour() %2 )
        date = date.addSecs( 60*60 );

    DateViewHandler::init( QDateTime( date.date(), QTime( date.time().hour(), 0, 0 ) ) );
}

bool DayViewHandler::isMajorUnit( int unit )
{
    int h = date(unit).time().hour();
    return h == 12 || h == 0;
}

bool DayViewHandler::isMidUnit( int unit )
{
    int h = date(unit).time().hour();
    return h == 6 || h == 18;
}

QString DayViewHandler::text( int unit )
{
    return date(unit).toString( QString::fromLatin1( "d/M - h:00" ) );
}

QDateTime DayViewHandler::date(int unit, QDateTime reference )
{
    if ( reference.isNull() ) reference = _startDate;
    return reference.addSecs( 2*60*60*unit );
}





void HourViewHandler::init( const QDateTime& startDate)
{
    DateViewHandler::init( QDateTime( startDate.date(),
                                      QTime( startDate.time().hour(), 10 * (int) floor(startDate.time().minute()/10.0), 0 ) ) );
}

bool HourViewHandler::isMajorUnit( int unit )
{
    return date(unit).time().minute() == 0;
}

bool HourViewHandler::isMidUnit( int unit )
{
    int min = date(unit).time().minute();
    return min == 30;
}

QString HourViewHandler::text( int unit )
{
    return date(unit).toString( QString::fromLatin1( "h:00" ) );
}

QDateTime HourViewHandler::date(int unit, QDateTime reference )
{
    if ( reference.isNull() ) reference = _startDate;
    return reference.addSecs( 60 * 10 * unit );
}

