#include "imagedaterange.h"
ImageDateRange::ImageDateRange( const ImageDate& from, const ImageDate& to )
    : _imageStart( from ), _imageEnd( to )
{
}

ImageDateRange::ImageDateRange()
{
}

ImageDateRange::MatchType ImageDateRange::includes( const ImageDateRange& searchRange )
{
    // We don't really want to include images without a year, as they clutter up things too much.
    if ( _imageStart.year() == 0  || ( !_imageEnd.isNull() && _imageEnd.year() == 0 ) )
        return DontMatch;

    ImageDate searchStart = searchRange.start();
    ImageDate searchEnd = searchRange.end();

    // We always want a range, so if no range is specified, then copy from-date to to-date.
    ImageDate imageEnd( _imageEnd );
    if ( _imageEnd.isNull() )
        imageEnd = _imageStart;
    if ( searchEnd.isNull() )
        searchEnd = searchStart;

//    qDebug("%s <= %s && %s >= %s (%d && %d)", searchStart.min().toString().latin1(), _imageStart.min().toString().latin1(), searchEnd.max().toString().latin1(), imageEnd.max().toString().latin1(), searchStart.min() <= _imageStart.min(), searchEnd.max() >= imageEnd.max() );

    if ( searchStart.min() <= _imageStart.min() && searchEnd.max() >= imageEnd.max() )
        return ExactMatch;

    if ( searchStart.min() <= imageEnd.max() && searchEnd.max() >= _imageStart.min() ) {
        return RangeMatch;
    }
    return DontMatch;
}

ImageDate ImageDateRange::start() const
{
    return _imageStart;
}

ImageDate ImageDateRange::end() const
{
    return _imageEnd;
}

bool ImageDateRange::operator<(const ImageDateRange& other ) const
{
    return _imageStart < other._imageStart ||
        ( _imageStart == other._imageStart && _imageEnd < other._imageEnd );
}
